==> checker-3.52.0.jar: annotated-jdk/src/jdk.management.agent/share/classes/sun/management/jdp/JdpJmxPacket.java <==
/*
 * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.management.jdp;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.UUID;

public final class JdpJmxPacket extends JdpGenericPacket implements JdpPacket {

    public final static String UUID_KEY;

    public final static String MAIN_CLASS_KEY;

    public final static String JMX_SERVICE_URL_KEY;

    public final static String INSTANCE_NAME_KEY;

    public final static String PROCESS_ID_KEY;

    public final static String RMI_HOSTNAME_KEY;

    public final static String BROADCAST_INTERVAL_KEY;

    public JdpJmxPacket(UUID id, String jmxServiceUrl) {
    }

    public JdpJmxPacket(byte[] data) throws JdpException {
    }

    public void setMainClass(String mainClass);

    public void setInstanceName(String instanceName);

    public UUID getId();

    public String getMainClass();

    public String getJmxServiceUrl();

    public String getInstanceName();

    public String getProcessId();

    public void setProcessId(String processId);

    public String getRmiHostname();

    public void setRmiHostname(String rmiHostname);

    public String getBroadcastInterval();

    public void setBroadcastInterval(String broadcastInterval);

    @Override
    public byte[] getPacketData() throws IOException;

    @Override
    public int hashCode();

    @Override
    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object o);
}

==> checker-3.53.1.jar: annotated-jdk/src/jdk.management.agent/share/classes/sun/management/jdp/JdpJmxPacket.java <==
/*
 * Copyright (c) 2013, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.management.jdp;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.UUID;

public final class JdpJmxPacket extends JdpGenericPacket implements JdpPacket {

    public static final String UUID_KEY;

    public static final String MAIN_CLASS_KEY;

    public static final String JMX_SERVICE_URL_KEY;

    public static final String INSTANCE_NAME_KEY;

    public static final String PROCESS_ID_KEY;

    public static final String RMI_HOSTNAME_KEY;

    public static final String BROADCAST_INTERVAL_KEY;

    public JdpJmxPacket(UUID id, String jmxServiceUrl) {
    }

    public JdpJmxPacket(byte[] data) throws JdpException {
    }

    public void setMainClass(String mainClass);

    public void setInstanceName(String instanceName);

    public UUID getId();

    public String getMainClass();

    public String getJmxServiceUrl();

    public String getInstanceName();

    public String getProcessId();

    public void setProcessId(String processId);

    public String getRmiHostname();

    public void setRmiHostname(String rmiHostname);

    public String getBroadcastInterval();

    public void setBroadcastInterval(String broadcastInterval);

    @Override
    public byte[] getPacketData() throws IOException;

    @Override
    public int hashCode();

    @Override
    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object o);
}
